pm4py.algo.filtering.common.end\_activities package
===================================================

Submodules
----------

pm4py.algo.filtering.common.end\_activities.end\_activities\_common module
--------------------------------------------------------------------------

.. automodule:: pm4py.algo.filtering.common.end_activities.end_activities_common
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.filtering.common.end_activities
   :members:
   :undoc-members:
   :show-inheritance:
